@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.015000';
+$MetaCPAN::Client::VERSION = '2.016000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref >;
@@ -182,6 +182,10 @@ sub all {
     $params and !is_hashref($params)
         and croak "all: params must be a hashref";
 
+    if ( $params->{fields} and !is_arrayref($params->{fields}) ) {
+        $params->{fields} = [ split /,/ => $params->{fields} ];
+    }
+
     return $self->$type( { __MATCH_ALL__ => 1 }, $params );
 }
 
@@ -390,7 +394,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.015000
+version 2.016000
 
 =head1 SYNOPSIS
 
